# -*- mode: python; coding: utf-8 -*-
# Copyright (C) 2017-2019 by BDE ENS Paris-Saclay
# SPDX-License-Identifier: GPL-3.0-or-later

from django.contrib.admin import AdminSite
from django.utils.translation import gettext_lazy as _
from django.views.decorators.cache import never_cache

from media.models import Emprunt


class DatabaseAdmin(AdminSite):
    index_title = _('Welcome to the Mediatek database')

    @never_cache
    def index(self, request, extra_context=None):
        """
        Add borrowed item to admin index
        """
        response = super().index(request, extra_context)

        # User is always authenticated
        user_borrowed = Emprunt.objects.filter(user=request.user)
        response.context_data["borrowed_items"] = user_borrowed

        return response


admin_site = DatabaseAdmin()
